@@ -6,16 +6,18 @@ from isv.scripts.open_model import open_model
 
 import numpy as np
 import pandas as pd
+import os
 
 
 def predict_with_same_cnv_type(annotated_cnvs: pd.DataFrame, cnv_type: str):
     """Return model predictions for a selected dataframe
-`
+
     :param annotated_cnvs: Raw counts of genomic elements
     :param cnv_type: type of cnv
+
     :return: yhat: predicted values
     """
-    model = open_model(settings.model_dir + f'ISV_{cnv_type}.json')
+    model = open_model(os.path.join(settings.model_dir, f'ISV_{cnv_type}.json'))
     X = prepare(annotated_cnvs, cnv_type)
 
     if isinstance(model, xgb.core.Booster):
@@ -27,13 +29,14 @@ def predict_with_same_cnv_type(annotated_cnvs: pd.DataFrame, cnv_type: str):
     return yhat
 
 
-def predict(annotated_cnvs: pd.DataFrame, proba: bool = True, threshold=0.95):
+def predict(annotated_cnvs: pd.DataFrame, proba: bool = True, threshold: float = 0.95):
     """Predict bulk of CNVs with different cnv types
 
     :param annotated_cnvs: Annotated CNVs
     :param proba: whether probabilities should be calculated
-    :param threshold: probability threshold for classifying CNVs into three classes: Pathogenic (>= threshold),
+    :param threshold: probability threshold for classifying CNVs into three classes: Pathogenic (>= threshold), \
     Uncertain significance ((1-threshold, threshold)) or Benign (<= 1 - threshold)
+
     :return: predictions
     """
 
