@@ -1,4 +1,5 @@
 import pandas as pd
+import os
 from sklearn.preprocessing import RobustScaler
 
 from isv.scripts.constants import LOSS_ATTRIBUTES, GAIN_ATTRIBUTES
@@ -13,6 +14,7 @@ def prepare(X, cnv_type, return_train=False):
     :param cnv_type: type of the cnv == ["loss", "gain"]
     :param X: pandas dataframe
     :param return_train: specify if transformed train data should be returned
+
     :return X: transformed dataframe if return_train is False. else tuple (X, X_train)
     """
 
@@ -21,7 +23,7 @@ def prepare(X, cnv_type, return_train=False):
     else:
         attributes = GAIN_ATTRIBUTES
 
-    train_data_path = settings.data_dir + f'train_{cnv_type}.tsv.gz'
+    train_data_path = os.path.join(settings.data_dir, f'train_{cnv_type}.tsv.gz')
     X_train = pd.read_csv(train_data_path, compression='gzip', sep='\t')
 
     # Train
